@@ -9,6 +9,7 @@ import 'package:dailyanimelist/enums.dart';
 import 'package:dailyanimelist/generated/l10n.dart';
 import 'package:dailyanimelist/main.dart';
 import 'package:dailyanimelist/pages/animedetailed/videoswidget.dart';
+import 'package:dailyanimelist/pages/userpop.dart';
 import 'package:dailyanimelist/screens/generalsearchscreen.dart';
 import 'package:dailyanimelist/screens/homescreen.dart';
 import 'package:dailyanimelist/screens/user_profile.dart';
@@ -841,17 +842,18 @@ Widget iconAndText(
   );
 }
 
-Widget loadingBelowText({
-  String? text,
-  EdgeInsetsGeometry padding = EdgeInsets.zero,
-  MainAxisAlignment mainAxisAlignment = MainAxisAlignment.center,
-}) {
+Widget loadingBelowText(
+    {String? text,
+    EdgeInsetsGeometry padding = EdgeInsets.zero,
+    MainAxisAlignment mainAxisAlignment = MainAxisAlignment.center,
+    double topPadding = 0}) {
   if (text == null) {
     text = S.current.Loading_Content;
   }
   return Column(
     mainAxisAlignment: mainAxisAlignment,
     children: [
+      SizedBox(height: topPadding),
       loadingCenterColored,
       const SizedBox(height: 20),
       Padding(
@@ -1118,12 +1120,15 @@ gotoAuthPage() {
 }
 
 void showUserPage({required BuildContext context, required String username}) {
-  gotoPage(
+  showModalBottomSheet(
     context: context,
-    newPage: UserProfilePage(
-      username: username,
-      isSelf: false,
-    ),
+    isScrollControlled: true,
+    builder: (context) {
+      return UserPopSlideOpenPage(
+        username: username,
+        isSelf: false,
+      );
+    },
   );
 }
 
